sca drop _all

********Set current directory to the folder where the code and data are saved
cd " "


use "raw_data.dta", clear


/*Dictionary of variables in INPUT data (raw_data.dta)
SessionDate: Day and time when the session was conducted
SessionType: Three types of session per treatment depending on values for continuation of supergames (see footnote 12 in the paper for details).
s:           Session index, goes from 1 to 18 [6 treatments, 3 sessions per treatment]
Treatment:   1 "Easy-Endog" 2 "Easy-Exog" 3 "Easy-Static"  4 "Diff-Endog" 5 "Diff-Exog" 6 "Diff-Static"
Cycle:       Supergame, goes from 1 to 15.
t:           Round within the supergame
i:           id for each subject in the experiment. 14 subjects per session, 18 sessions, 252 participants.
ic:          indexes the id, cycle pair. That is, creates a unique id per id-cycle.
Subjectid:   Subject id as provided by ztree in each session. Goes from 1 to 14.
Partnerid:   id of the participant the subject is interacting with in the cycle. Goes from 1 to 14. 
partner1id:  min of Partnerid and Subjectid.
partner2id:  max of Partnerid and Subjectid.
Action:      Subject's choice in the round. 1: Cooperate, 2: Defect.
PartnerAction: Partner's choice in the round. 1: Cooperate, 2: Defect. 
State:       0: Low, 1: High. 
*/

/*Dictionary of variables created by the PRELIMINARIES part of this code
outcome:     Result of the round's actions without coding which state the round took place. -1 "--" 1 "(C,C)" 2 "(C,D)" 3 "(D,C)" 4 "(D,D)" 
Outcome:     Result of the round's actions coding which state the round took place. -1 "--" 1 "L,(C,C)" 2 "L,(C,D)" 3 "L,(D,C)" 4 "L,(D,D)"  5 "H,(C,C)" 6 "H,(C,D)" 7 "H,(D,C)" 8 "H,(D,D)" 
StateL:      State in the previous round.
StateLX:     State X rounds ago, where X={2,3,4}.
outcomeL:    outcome last round.
OutcomeL:    Outcome last round.
outcomeLX:   outcome X rounds ago, where X={2,3,4}.
OutcomeLX:   Outcome X rounds ago, where X={2,3,4}.
ActionL:     Action last round.
PartnerActionL: Partner's action last round.
Cooperate:   dummy that takes value 1 if the subject cooperates, 0 otherwise. 
Defect:      dummy that takes value 1 if the subject defects, 0 otherwise.
CooperateOtherL: dummy that takes value 1 if the other cooperated in the previous period.
Exog:            dummy that takes value 1 if the treatment is Exog.
Endog:           dummy that takes value 1 if the treatment is Endog.
Static:          dummy that takes value 1 if the treatment is Static.
*/

set more 1

*****PRELIMINARIES: Creating variables that will be useful for generating tables later.

gen     outcome = 1 if Action==1 & PartnerAction==1
replace outcome = 2 if Action==1 & PartnerAction==2
replace outcome = 3 if Action==2 & PartnerAction==1
replace outcome = 4 if Action==2 & PartnerAction==2
label define outcomeLabel  -1 "--" 1 "(C,C)" 2 "(C,D)" 3 "(D,C)" 4 "(D,D)"
label values outcome outcomeLabel

gen     Outcome = 1 if Action==1 & PartnerAction==1 & State==0
replace Outcome = 2 if Action==1 & PartnerAction==2 & State==0
replace Outcome = 3 if Action==2 & PartnerAction==1 & State==0
replace Outcome = 4 if Action==2 & PartnerAction==2 & State==0
replace Outcome = 5 if Action==1 & PartnerAction==1 & State==1
replace Outcome = 6 if Action==1 & PartnerAction==2 & State==1
replace Outcome = 7 if Action==2 & PartnerAction==1 & State==1
replace Outcome = 8 if Action==2 & PartnerAction==2 & State==1


label define OutcomeLabel  -1 "--" 1 "L,(C,C)" 2 "L,(C,D)" 3 "L,(D,C)" 4 "L,(D,D)"  5 "H,(C,C)" 6 "H,(C,D)" 7 "H,(D,C)" 8 "H,(D,D)"
label values Outcome OutcomeLabel

sort ic t
by ic: gen StateL=State[_n-1]
by ic: gen StateL2=State[_n-2]
by ic: gen StateL3=State[_n-3]
by ic: gen StateL4=State[_n-4]
by ic: gen outcomeL=outcome[_n-1]
by ic: gen OutcomeL=Outcome[_n-1]
by ic: gen outcomeL2=outcome[_n-2]
by ic: gen OutcomeL2=Outcome[_n-2]
by ic: gen outcomeL3=outcome[_n-3]
by ic: gen OutcomeL3=Outcome[_n-3]
by ic: gen outcomeL4=outcome[_n-4]
by ic: gen OutcomeL4=Outcome[_n-4]
by ic: gen ActionL=Action[_n-1]
by ic: gen PartnerActionL=PartnerAction[_n-1]

replace StateL=-1 if StateL==.
replace StateL2=-1 if StateL2==.
replace StateL3=-1 if StateL3==.
replace StateL4=-1 if StateL4==.
replace OutcomeL=-1 if OutcomeL==.
replace outcomeL=-1 if outcomeL==.
replace OutcomeL2=-1 if OutcomeL2==.
replace outcomeL2=-1 if outcomeL2==.
replace OutcomeL3=-1 if OutcomeL3==.
replace outcomeL3=-1 if outcomeL3==.
replace OutcomeL4=-1 if OutcomeL4==.
replace outcomeL4=-1 if outcomeL4==.
replace ActionL=-1 if ActionL==.
replace PartnerActionL=-1 if ActionL==.

label values StateL StateLabel
label values OutcomeL OutcomeLabel
label values outcomeL outcomeLabel
label values ActionL ActionLabel
label values PartnerActionL PartnerActionLabel
label var State "State[t]" 
label var StateL "State[t-1]" 
label var StateL2 "State[t-2]" 
label var StateL3 "State[t-3]" 
label var StateL4 "State[t-4]"  
label var Outcome "State-Outcome[t]"
label var OutcomeL "State-Outcome[t-1]"
label var OutcomeL2 "State-Outcome[t-2]"
label var OutcomeL3 "State-Outcome[t-3]"
label var OutcomeL4 "State-Outcome[t-4]"
label var outcome "Outcome[t]"
label var outcomeL "Outcome[t-1]"
label var outcomeL2 "Outcome[t-2]"
label var outcomeL3 "Outcome[t-3]"
label var outcomeL4 "Outcome[t-4]"
label var Action "Action[t]"
label var ActionL "Action[t-1]"
label var PartnerActionL "PartnerAction[t-1]"

gen Cooperate=Action==1
gen Defect=Action==2
gen CooperateOtherL=PartnerActionL==2
gen Exog=Treatment==2 | Treatment==5
gen Endog=Treatment==1 | Treatment==4
gen Static=Treatment==3 | Treatment==6

gen Diff=Treatment>3
gen Easy=Treatment<4

gen EnE=Treatment==1
gen ExE=Treatment==2
gen StE=Treatment==3
gen EnD=Treatment==4
gen ExD=Treatment==5
gen StD=Treatment==6
******END PRELIMINARIES
**************************************************************************
*Section 3.1: Table 1
**************************************************************************
 
*Assemble Weights for State
foreach tVal of numlist 1/5 {
	foreach dVal of numlist 0/1 {
		qui sum State if Cycle>10 & t==`tVal' & Diff==`dVal' & Endog==1 
		qui local weight_`tVal'_`dVal'=r(mean)
		disp as text "Difficult: `dVal'; Period: `tVal':" as result `weight_`tVal'_`dVal''
	}
}
* Generate Indicator Variables
foreach trans in Ex St En {
	foreach tVal of numlist 1/5 {
		foreach sVal of numlist 0/1 { 
			gen `trans'E_`sVal'_`tVal'=(`trans'E==1 & t==`tVal' & State==`sVal')
			gen `trans'D_`sVal'_`tVal'=(`trans'D==1 & t==`tVal' & State==`sVal') 
		}

	}
}
**********************************************
* First Column Pair (Unweighted)
**********************************************
reg Cooperate StE StD ExE ExD EnE EnD if Cycle>10 & t<=5 ,noconstant cluster(i)
lincom StD-StE
lincom ExD-ExE
lincom EnD-EnE

/* Joint Test of Transition */ 
test EnE-StE=EnD-StD=0
test EnE-ExE=EnD-ExD=0
/* Separate Test of Transition */
lincom EnE-StE
lincom EnE-ExE
**********************************************
* Joint Test Just before Footnote 17
**********************************************
test EnD-EnE=StD-StE=ExD-ExE
/*What if expand to all cycles */
qui reg Cooperate StE StD ExE ExD EnE EnD if  t<=5 ,noconstant cluster(i)

lincom EnE-StE /* One sided test in paper */
lincom EnE-ExE /* One sided test in paper */

**********************************************
* Second Column Pair (Weighted)
**********************************************
qui reg Cooperate StE_* StD_* ExE_* ExD_* EnE EnD if Cycle>10 & t<=5 ,noconstant cluster(i)
foreach AA in St Ex {
disp "Weighted Coop in `AA'-Easy"
lincom (`AA'E_0_1+((1-`weight_2_0') *`AA'E_0_2+`weight_2_0'*`AA'E_1_2)+((1-`weight_3_0') *`AA'E_0_3+`weight_3_0'*`AA'E_1_3)+((1-`weight_4_0') *`AA'E_0_4+`weight_4_0'*`AA'E_1_4)+((1-`weight_5_0') *`AA'E_0_5+`weight_5_0'*`AA'E_1_5))/5

disp "Test Coop in `AA'-Easy against EnE"
lincom (`AA'E_0_1+((1-`weight_2_0') *`AA'E_0_2+`weight_2_0'*`AA'E_1_2)+((1-`weight_3_0') *`AA'E_0_3+`weight_3_0'*`AA'E_1_3)+((1-`weight_4_0') *`AA'E_0_4+`weight_4_0'*`AA'E_1_4)+((1-`weight_5_0') *`AA'E_0_5+`weight_5_0'*`AA'E_1_5))/5 -EnE

disp "Weighted Coop in `AA'-Difficult"
lincom (`AA'D_0_1+((1-`weight_2_1') *`AA'D_0_2+`weight_2_1'*`AA'D_1_2)+((1-`weight_3_1') *`AA'D_0_3+`weight_3_1'*`AA'D_1_3)+((1-`weight_4_1') *`AA'D_0_4+`weight_4_1'*`AA'D_1_4)+((1-`weight_5_1') *`AA'D_0_5+`weight_5_1'*`AA'D_1_5))/5


disp "Joint Test of Weighted Coop in `AA' against En"
test `AA'E_0_1+((1-`weight_2_0') *`AA'E_0_2+`weight_2_0'*`AA'E_1_2)+((1-`weight_3_0') *`AA'E_0_3+`weight_3_0'*`AA'E_1_3)+((1-`weight_4_0') *`AA'E_0_4+`weight_4_0'*`AA'E_1_4)+((1-`weight_5_0') *`AA'E_0_5+`weight_5_0'*`AA'E_1_5)-5*EnE=`AA'D_0_1+((1-`weight_2_1') *`AA'D_0_2+`weight_2_1'*`AA'D_1_2)+((1-`weight_3_1') *`AA'D_0_3+`weight_3_1'*`AA'D_1_3)+((1-`weight_4_1') *`AA'D_0_4+`weight_4_1'*`AA'D_1_4)+((1-`weight_5_1') *`AA'D_0_5+`weight_5_1'*`AA'D_1_5)-5*EnD=0

}
qui drop EnE_* EnD_*  ExE_* ExD_*  StE_* StD_*
**********************************************
* Third Column Pair (Low State)
**********************************************
reg Cooperate StE StD ExE ExD EnE EnD if Cycle>10 & t<=5 & State==0 ,noconstant cluster(i)
* Relative shift in size
testnl (_b[ExD]/_b[ExE]-1)-(_b[EnD]/_b[EnE]-1)=(_b[StD]/_b[StE]-1)-(_b[EnD]/_b[EnE]-1)=0
**********************************************
* Fourth Column Pair (High State)
**********************************************
reg Cooperate StE StD ExE ExD EnE EnD if Cycle>10 & t<=5 & State==1 ,noconstant cluster(i)
* Relative shift in size
testnl (_b[ExD]/_b[ExE]-1)-(_b[EnD]/_b[EnE]-1)=(_b[StD]/_b[StE]-1)-(_b[EnD]/_b[EnE]-1)=0
**********************************************
* Footnote 16
**********************************************
bysort Treatment: sum State if  t<=5

**************************************************************************
*Section 3.2: Table 3, statements in text and footnotes
**************************************************************************
*Endogenous Treatments
************************************
gen     focus=1 if (outcomeL2==1 & ActionL==1) & t==3
replace focus=0 if (outcomeL2!=1 | ActionL!=1) & t==3

tab focus Treatment if Treatment==1|Treatment==4, col nof /*footnote 19*/

gen T1_D =(Treatment==1 & CooperateOtherL==1)
gen T1_C =(Treatment==1 & CooperateOtherL==0)
gen T4_D =(Treatment==4 & CooperateOtherL==1)
gen T4_C =(Treatment==4 & CooperateOtherL==0)

reg Cooperate T1_D T1_C T4_D T4_C if focus==1 & Endog==1, nocons cluster(i) /*last column of Table 3*/
test T1_D=T1_C /*footnote 20*/
test T4_D=T4_C /*footnote 20*/
test T1_D-T1_C=T4_D-T4_C  /*footnote 21*/

************************************
*Exogenous Treatments
************************************
drop focus

gen     focus=1 if (ActionL==1) & t==2
replace focus=0 if (ActionL!=1) & t==2

tab focus Treatment if Treatment==2|Treatment==5, col nof /*footnote 22*/

gen T2_D =(Treatment==2 & CooperateOtherL==1)
gen T2_C =(Treatment==2 & CooperateOtherL==0)
gen T5_D =(Treatment==5 & CooperateOtherL==1)
gen T5_C =(Treatment==5 & CooperateOtherL==0)

reg Cooperate T2_D T2_C T5_D T5_C if focus==1 & Exog==1 & State==0, nocons cluster(i) /*low-state column for Exog treatments of Table 3*/
test T2_D=T2_C /*footnote 24*/
test T5_D=T5_C /*footnote 25*/

reg Cooperate T2_D T2_C T5_D T5_C if focus==1 & Exog==1 & State==1, nocons cluster(i) /*high-state column for Exog treatments of Table 3*/
test T2_D=T2_C /*footnote 24*/
test T5_D=T5_C /*footnote 25*/

************************************
*Static Treatments
************************************
tab focus Treatment if Treatment==3|Treatment==6, col nof /*footnote 22*/

gen T3_D =(Treatment==3 & CooperateOtherL==1)
gen T3_C =(Treatment==3 & CooperateOtherL==0)
gen T6_D =(Treatment==6 & CooperateOtherL==1)
gen T6_C =(Treatment==6 & CooperateOtherL==0)

reg Cooperate T3_D T6_D T3_C T6_C if focus==1 & Static==1 & State==0, nocons cluster(i) /*low-state column for Static treatments of Table 3*/
reg Cooperate T3_D T6_D T3_C T6_C if focus==1 & Static==1 & State==1, nocons cluster(i) /*low-state column for Static treatments of Table 3*/


**************************************************************************
*Section 3.2: Table 4
**************************************************************************
quietly{
/*Define panel vars*/
xtset ic t
/* For each possible Markov strategy define a deviation from that strategy in the data*/ 
gen MccError=(Cooperate==0) 
gen McdError=(Cooperate==0 & State==0) | (Cooperate==1 & State==1)
gen MdcError=(Cooperate==1 & State==0) | (Cooperate==0 & State==1)
gen MddError=(Cooperate==1)

gen PCooperate=PartnerAction==1
* Define Sdd Action & Error
gen SddCoop=1 if t==1
replace SddCoop=(L.SddCoop==1 & L.PCooperate==1 & L.Cooperate==1) if t>1
gen SddError=Cooperate!=SddCoop

* Define Xdd Action & Error
gen XddCoop=1 if t==1
replace XddCoop=(L.XddCoop==1 & L.PCooperate==1 & State==0) | (L.XddCoop==1 & State==1) if t>1
gen XddAction=(XddCoop==1 & State==0)
gen XddError=Cooperate!=XddAction
*Reordering in Table 4
recode Treatment (1=1)(4=2)(2=3)(5=4)(3=5)(6=6), gen(Table4Order)
preserve
collapse MccError McdError MdcError MddError SddCoop SddError XddError Table4Order if Cycle>10 & t<=5 & t>=1, by(Treatment)
*Calculate BestFitting Markov
gen BestMarkov=1-min(MccError, McdError, MdcError, MddError)
gen MPE=1-MddError
*Calculate BestSPE by treatment
gen BestSPE=1- SddError if Treatment<=4    /* Sdd equilibrium here*/
replace BestSPE=1-XddError if Treatment>=5 /* Sdd not equilibrium here*/
sort Table4Order
}
**********************************************
*       Outcomes for Rounds 1 to 5
**********************************************
li Treatment MPE BestMarkov BestSPE
**********************************************
*       Totals
**********************************************
sum MPE BestMarkov BestSPE
qui{
restore 
preserve

collapse MccError McdError MdcError MddError SddCoop SddError XddError Table4Order if Cycle>10 & t==5, by(Treatment)
gen BestMarkov=1-min(MccError, McdError, MdcError, MddError)
gen MPE=1-MddError
gen BestSPE=1- SddError if Treatment<=4
replace BestSPE=1-XddError if Treatment>=5
sort Table4Order
}
**********************************************
*       Outcomes for Rounds 1 to 5
**********************************************
li Treatment MPE BestMarkov BestSPE
**********************************************
*       Totals
**********************************************
sum MPE BestMarkov BestSPE
qui restore 
**********************************************


**********************************************
*Section 3.3: Table 5
**********************************************

qui gen JointCoop= Action==1 & PartnerAction==1
**********************************************
*Initial ( Regression Selects only one of the two partners for observation)
reg JointCoop StE StD ExE ExD EnE EnD if t==1 & Cycle>10 & State==0 & Subjectid<Partnerid, nocons
**********************************************
*Tests of Parameterization
**********************************************
lincom StE-StD  
lincom ExE-ExD
lincom EnE-EnD
**********************************************
*Ongoing ( Regression Selects only one of the two partners for observatio, drops En-E En-D)
**********************************************
qui: xtset ic t
qui: gen L4JointCoop=L4.JointCoop /*Joint Cooperation 4 periods before */
reg JointCoop StE StD ExE ExD if t==5 & Cycle>10 & State==0 &  L4JointCoop==1 & Subjectid<Partnerid & Treatment!=1  & Treatment!=4, nocons
**********************************************
*Tests of Parameterization
**********************************************
lincom StE-StD
lincom ExE-ExD

**********************************************
*Section 3.3: Table 6
**********************************************
reg Cooperate StE StD ExE ExD EnE EnD if Cycle==1 & t==1 & State==0, noconstant
**********************************************
*Parameterization Effect Tests
lincom StE-StD
lincom ExE-ExD
lincom EnE-EnD
**********************************************
*Footnote 35 tests
test EnE-StE=EnD-StD=0 /*Endog=Static*/
test EnE-ExE=EnD-ExD=0 /*Endog=Exog*/
test EnE-EnD=ExE-ExD=StE-StD=0 /*Diff=Easy*/
qui{
gen ExED=ExD+ExE
gen EnED=EnD+EnE
gen StED=StD+StE
}
*Equivalent to the Tests if Pooling Diff and Easy
reg Cooperate StED ExED EnED if Cycle==1 & t==1 & State==0, noconstant
lincom EnED-ExED /*Endog=Static*/
lincom EnED-StED /*Endog=Exog*/
**********************************************
* In text Exposure regression
**********************************************
qui{
bysort i:egen HighTotal=total(State*(Cycle<=10)) if t==1
gen Exposure=(HighTotal-5)/sqrt(2.5)
}
reg Cooperate StE StD Exposure if (StE==1 | StD==1) & Cycle>10 & t==1 & State==0 , nocons cluster(i)

**********************************************
*Check of Approximate Equivalence to Probit Marginal Effects
**********************************************
probit Cooperate i.StE i.StD c.Exposure if (StE==1 | StD==1) & Cycle>10 & t==1 & State==0 , nocons cluster(i)
margin, at(StE=1 StD=0 Exposure=0)
margin, at(StE=0 StD=1 Exposure=0)
margin, dydx(Exposure)


